{
  config,
  pkgs,
  lib,
  ...
}:
with lib; let
  psCfg = config.pub-solar;
  xdg = config.home-manager.users."${psCfg.user.name}".xdg;
in {
  imports = [
    ./configuration.nix
  ];

  config = {
    pub-solar.paranoia.enable = true;
    pub-solar.core.hibernation.resumeDevice = "/dev/dm-0";
    pub-solar.core.hibernation.resumeOffset = 15296512;

    hardware.cpu.intel.updateMicrocode = true;

    networking.firewall.allowedTCPPorts = [5000];

    networking.networkmanager.wifi.backend = mkForce "wpa_supplicant";

    services.printing.drivers = [
      pkgs.cups-brother-hl3140cw
    ];

    home-manager = with pkgs;
      pkgs.lib.setAttrByPath ["users" psCfg.user.name] {
        xdg.configFile = mkIf psCfg.sway.enable {
          "sway/config.d/10-screens.conf".source = ./.config/sway/config.d/screens.conf;
          "sway/config.d/10-autostart.conf".source = ./.config/sway/config.d/autostart.conf;
          "sway/config.d/10-input-defaults.conf".source = ./.config/sway/config.d/input-defaults.conf;
          "sway/config.d/10-custom-keybindings.conf".source = ./.config/sway/config.d/custom-keybindings.conf;
        };

        home.packages = [
          inkscape
        ];
      };

    # For OpenProject development with https
    security.pki.certificates = [
      (builtins.readFile ./step-roots.pem)
    ];
  };
}
